==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebPageCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPageCancellableEventArgsDescriptionMetadata.a);
            WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
        }
        static d(a) {
            WebPageCancellableEventArgsDescriptionMetadata.b(a);
            a.aa("WebPageCancellableEventArgs", () => new WebPageCancellableEventArgsDescription());
            a.z("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPageCancellableEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageCancellableEventArgsDetailDescriptionMetadata } from "./WebPageCancellableEventArgsDetailDescriptionMetadata";
import { WebPageCancellableEventArgsDescription } from "./WebPageCancellableEventArgsDescription";
/**
 * @hidden
 */
export let WebPageCancellableEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPageCancellableEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebPageCancellableEventArgsDescriptionMetadata.a == null) {
                WebPageCancellableEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPageCancellableEventArgsDescriptionMetadata.c(WebPageCancellableEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebPageCancellableEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPageCancellableEventArgsDescriptionMetadata.a);
            WebPageCancellableEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PageCancellableEventArgs");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebPageCancellableEventArgsDetail");
        }
        static d(a) {
            WebPageCancellableEventArgsDescriptionMetadata.b(a);
            a.ac("WebPageCancellableEventArgs", () => new WebPageCancellableEventArgsDescription());
            a.ab("WebPageCancellableEventArgs", WebPageCancellableEventArgsDescriptionMetadata.a);
        }
    }
    WebPageCancellableEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPageCancellableEventArgsDescriptionMetadata, 'WebPageCancellableEventArgsDescriptionMetadata');
    WebPageCancellableEventArgsDescriptionMetadata.a = null;
    return WebPageCancellableEventArgsDescriptionMetadata;
})();
